@@ -92,6 +92,21 @@ def process_model(model_description_info:ModelDescriptionInfo, vcf_accessor:VcfA
     data = Data(vcf_accessor, allele_freq_accessor, sample_name, pop, model)
     return data.compute_model(), module.trait_was_prepared_for_population
 
+def parse_model(path: str):
+    model_path = expand_path(path)
+    model_fname = os.path.basename(model_path)
+    description_path = model_path.replace('.py', '.json')
+    description = [description_path] if os.path.exists(description_path) else []
+    plot_data_path_str = model_path.replace('_traits/', '_data/').replace('_model.py', '_data.json')
+    plot_data_path = plot_data_path_str if os.path.exists(plot_data_path_str) else None
+    model_info = ModelDescriptionInfo(
+        model_fname = model_fname,
+        model_path = model_path,
+        desc_paths = description,
+        plot_data_path = plot_data_path
+    )
+    return model_info
+
 def main(args = sys.argv[1:]):
     parser = argparse.ArgumentParser(description='')  # todo dodać opis
     parser.add_argument('--vcf', nargs='+', required=True,
@@ -113,7 +128,8 @@ def main(args = sys.argv[1:]):
                         help='Directories containing models from the inside of this repo')
     # parser.add_argument('--actionable_dir', type=str, default='',
     #                     help='Directory containing "actionable" models')  # default='vitalleo_actionable'
-    parser.add_argument('--models_and_descriptions_path', type=str, default='', help="Path to a directory containing models and corresponding_descriptions")
+    parser.add_argument('--models_path', type=str, default='', help="Path to a directory containing models and corresponding_descriptions")
+    parser.add_argument('--model', action='append', help="Path to model")
     parser.add_argument('--mapping_json', type=str, default='', help="A file containing mapping between models and descriptions")
     parser.add_argument('--af', type=str, default='',
                         help="A file containing allele freq data")
@@ -145,10 +161,19 @@ def main(args = sys.argv[1:]):
     #    raise RuntimeError('You supplied mapping file, but no models')
 
     # coupling model files with descriptions and plot data
-    directories = [abspath_to_model_dir_from_repo(trait_dir) for trait_dir in parsed_args.traits_dirs] or []
-    print(directories)
-    model_files_info = {}
-    print(model_files_info)
+    #directories = [abspath_to_model_dir_from_repo(trait_dir) for trait_dir in parsed_args.traits_dirs] or []
+    #print(directories)
+    #directories = []
+    models_info = {}
+    for model in parsed_args.model:
+        model_info = parse_model(model)
+        models_info[model_info.model_path] = model_info
+    directory = str(os.path.join(parsed_args.models_path, '*_{}_model.py'.format(parsed_args.population)))
+    for model in glob.glob(directory):
+        model_info = parse_model(model)
+        models_info[model_info.model_path] = model_info
+
+    #print(model_files_info)
     # if parsed_args.mapping_json:
     #     with open(expand_path(parsed_args.mapping_json)) as f:
     #         models_descriptions_mappings = json.load(f)
@@ -157,23 +182,26 @@ def main(args = sys.argv[1:]):
     #                                          logger))
     # elif parsed_args.models_and_descriptions_path:
     #     directories.append(parsed_args.models_and_descriptions_path)
-    directories.append(parsed_args.models_and_descriptions_path)
-    print(directories)
-    model_files_info.update(load_models_when_mapping_absent(directories, parsed_args.population, logger))
-    print(model_files_info)
-    if not model_files_info:
+    #directories.append(parsed_args.models_and_descriptions_path)
+    #print(directories)
+    
+    if not models_info:
         raise RuntimeError("No models loaded. Exiting.")
 
     # create data accessors
     #initial_accessor = VcfAccessor([expand_path(path) for path in parsed_args.curated_initial_vcfs[0]])
 
     vcf_accessor = VcfAccessor(expand_path(parsed_args.vcf[0]))
-    allele_accessor = VcfAccessor(expand_path(parsed_args.af))#AlleleFrequencyAccessor(allele_freq_json_path=allele_freq_path)
+
+    if parsed_args.af == "":
+        allele_accessor = None
+    else:    
+        allele_accessor = VcfAccessor(expand_path(parsed_args.af))#AlleleFrequencyAccessor(allele_freq_json_path=allele_freq_path)
     sample_names = vcf_accessor.sample_names
     
     for sample_name in sample_names:
          results_representations = {}
-         for model_path, model_desc_info in model_files_info.items():
+         for model_path, model_desc_info in models_info.items():
              res, pop_in_model = process_model(model_desc_info, vcf_accessor, allele_accessor, population, sample_name)
              results_representations[model_path] = create_res_representation_for_model(res, model_desc_info, pop_in_model)
          with open(os.path.join(out_dir, f'{sample_name}.sample.json'), 'w') as f:
