@@ -3,7 +3,7 @@ from polygenic import polygenic
 
 class TestSequery(TestCase):
     def testCommandLine(self):
-        polygenic.main(["--vcf", "/home/marpiech/data/clustered_204800980122_R01C02.vcf.gz", "--af", "/home/marpiech/data/af.vcf.gz", "--log_file", "/dev/null", "--models_and_descriptions_path", "/home/marpiech/data", "--population", "eas", "--out_dir", "/tmp/polygenic"])
+        polygenic.main(["--vcf", "/home/marpiech/data/clustered_204800980122_R01C02.vcf.gz", "--log_file", "/dev/null", "--model", "/home/marpiech/data/breast_cancer_eas_model.py", "--population", "eas", "--out_dir", "/tmp/polygenic"])
         self.assertEqual('1', '1')
 
 #class TestSequeryShort(TestCase):
